@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11784 2019-11-28 09:39:09Z Lavender $
+# $Id: __init__.py 11793 2019-12-11 15:00:31Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-11-28 18:39:09 +0900 (週四, 28 十一月 2019) $
-# $Revision: 11784 $
+# $Date: 2019-12-12 00:00:31 +0900 (週四, 12 十二月 2019) $
+# $Revision: 11793 $
 
 import os
 import sys
@@ -560,8 +560,13 @@ def attachShopURLs(settings, urlpatterns):
         url(r'^shop/dashboard/bonus/', 
             staff_member_required(views.BonusSettingsView.as_view()), 
             name="bonusSettings"),
+        url(r'^shop/dashboard/users/(?P<pk>-?\d+)/bonus/update/$',
+            staff_member_required(views.updateBonus),
+            name='updateBonus'),
         url(r'^shop/basket/bonus',
             views.useBonus, name="useBonus"),
+        url(r'^shop/send_confirm_code/$', views.sendConfirmCode, 
+            name='sendConfirmCode'),
     )
     if VERSION >= (2, 0, 0):
         from django.apps import apps
@@ -613,7 +618,8 @@ def attachShopURLs(settings, urlpatterns):
             urlpatterns += patterns('',          
                 url(r'^shop/dashboard/paypal/express/', application.urls),
                 url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
-                    views.SuccessResponseView.as_view(), name='paypal-place-order'),
+                    views.SuccessResponseView.as_view(), 
+                    name='paypal-place-order'),
                 url(r'^checkout/paypal/', include('paypal.express.urls')),
             )
 
@@ -771,30 +777,31 @@ def buildAPIForm(submission, request, apiName, extra={}):
         return ''
 
     MERCHANT_TRADE_NO_LEN = 20
-
-    total = submission['order_total'].excl_tax
-
-    # USD
-    if submission['order_total'].currency == 'USD':
-        total = total * Decimal(twder.now('USD')[2]) # 當前匯率
-
+    
     basket = submission['basket']
-    
-    # item name
-    itemName = utf8('')
-    for index, line in enumerate(basket.all_lines()):
-        product = line.product
-        
-        productName = product.get_title()
-        itemName += utf8(productName)
-        
-        itemName += utf8(_(' %(dollar)d dollar X %(number)d#') % {
-                    'dollar': line.price_excl_tax, 'number': line.quantity})
-    itemName += utf8(_("shipping charge %(dollar)d dollar X 1") % {
-                     'dollar': submission['shipping_charge'].excl_tax})
 
-    itemName = utf8(itemName)
-    
+    if not apiName == ECPAY_MAP:
+        total = submission['order_total'].excl_tax
+
+        # USD
+        if submission['order_total'].currency == 'USD':
+            total = total * Decimal(twder.now('USD')[2]) # 當前匯率
+        
+        # item name
+        itemName = utf8('')
+        for index, line in enumerate(basket.all_lines()):
+            product = line.product
+            
+            productName = product.get_title()
+            itemName += utf8(productName)
+            
+            itemName += utf8(_(' %(dollar)d dollar X %(number)d#') % {
+                        'dollar': line.price_excl_tax, 'number': line.quantity})
+        itemName += utf8(_("shipping charge %(dollar)d dollar X 1") % {
+                         'dollar': submission['shipping_charge'].excl_tax})
+
+        itemName = utf8(itemName)
+        
     # merchantTradeNo
     basketId = basket.id
     tradeNo = 'BASKETID%d' % basketId
