@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11781 2019-11-19 11:15:37Z Lavender $
+# $Id: forms.py 11793 2019-12-11 15:00:31Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,16 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-11-19 20:15:37 +0900 (週二, 19 十一月 2019) $
-# $Revision: 11781 $
+# $Date: 2019-12-12 00:00:31 +0900 (週四, 12 十二月 2019) $
+# $Revision: 11793 $
 
 import os
 import re
 import hashlib
 import datetime
 
+from time import gmtime, strftime
+
 from django import forms
 from django.conf import settings
 from django.utils.translation import gettext_lazy as _
@@ -612,7 +614,8 @@ if VERSION >= (2, 0, 0):
 class BonusSettingsForm(forms.ModelForm):
     class Meta:
         model = BonusSettings
-        fields = ['consumption', 'percent', 'discount', 'limit']
+        fields = ['consumption', 'percent', 'discount', 
+                  'limit', 'includeRange', 'excludeRange']
         
 class BonusForm(forms.Form):
     quantity = forms.IntegerField(
@@ -620,7 +623,71 @@ class BonusForm(forms.Form):
         
     def __init__(self):
         super().__init__()
-        
+ 
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3289#ticket 
+from oscar.apps.customer import views as customerViews
 
+_EmailUserCreationForm = get_class("customer.forms", "EmailUserCreationForm")
+        
+class EmailUserCreationForm(_EmailUserCreationForm):
+    timeStamp = forms.CharField(
+        label=_("Time Stamp"),
+        widget=forms.HiddenInput,
+        required=True
+    )
+
+    confirmationCode = forms.CharField(
+        label=_("Confirm Code"),
+        max_length=30,
+        widget=forms.TextInput(attrs={'class' : 'form-control'}),
+        required=True
+    )
+    
+    def __init__(self, *args, **kwargs):
+        super(EmailUserCreationForm, self).__init__(*args, **kwargs)
+        if 'initial' in kwargs:
+            self.fields['email'].initial = kwargs['initial']['email']
+
+        self.fields['timeStamp'].initial = strftime(
+            "%Y-%m-%d %H:%M:%S", gmtime())
+
+    def clean_confirmationCode(self):
+        """
+        Checks for whether confirm code is correct.
+        """
+        confirmationCode = self.cleaned_data['confirmationCode']
+
+        m = hashlib.md5()
+        m.update(self.cleaned_data.get('email', '').encode())
+        m.update(self.cleaned_data.get('timeStamp', '').encode())
+        code = m.hexdigest()[5:10]
+
+        if not code == confirmationCode:
+            raise forms.ValidationError(
+                _("Confirm code doesn't match."))
+        return confirmationCode
+        
+customerViews.AccountRegistrationView.form_class = EmailUserCreationForm
+
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3290#ticket
+
+_OrderNoteForm = get_class("dashboard.orders.forms", "OrderNoteForm")
+
+class OrderNoteForm(_OrderNoteForm):
+
+    CHOICES = [
+        ('Normal', _('Normal')),
+        ('Display for customer', _('Display for customer')),
+    ]
+
+    def __init__(self, order, user, *args, **kwargs):
+        super().__init__(order, user, *args, **kwargs)
+        self.fields['note_type'].widget.choices = self.CHOICES
+
+    class Meta(_OrderNoteForm.Meta):
+        fields = ['note_type', 'message',]
+        widgets = {
+            'note_type': forms.Select,
+        }
         
     
