@@ -147,6 +147,7 @@ class BonusRecord(models.Model):
     order = models.ForeignKey(
         Order,
         verbose_name=_("Order"),
+        null=True,
     )
     
     
@@ -154,6 +155,8 @@ class BonusRecord(models.Model):
         verbose_name=_("Use"), default=0)
     receive = models.PositiveIntegerField(
         verbose_name=_("Receive"), default=0)
+    adjust = models.PositiveIntegerField(
+        verbose_name=_("Adjust"), default=0)
         
     createdTime = models.DateTimeField(_("Created Time"), auto_now_add=True)
     
@@ -165,9 +168,9 @@ User.bonusRecords = bonusRecords
     
 class BonusSettings(SingletonModel):
     consumption = models.PositiveIntegerField(
-        verbose_name=_("Consumption exceed"), default=0)
+        verbose_name=_("Consumption exceed(0 = no limit)"), default=0)
     percent = models.FloatField(
-        verbose_name=_("Percent of consumption turn into bouns"), default=0.0,
+        verbose_name=_("Percent of consumption turn into bouns(10 = 10%)"), default=0.0,
         validators=[MinValueValidator(0.0),],
     )
     discount = models.FloatField(
@@ -179,6 +182,23 @@ class BonusSettings(SingletonModel):
         validators=[MinValueValidator(-1),],
     )
     
+    includeRange = models.ForeignKey(
+        'offer.Range',
+        blank=True,
+        null=True,
+        on_delete=models.CASCADE,
+        verbose_name=_("Include range(default is all products)"),
+        related_name='bonusIncludeEange'
+    )
+    excludeRange = models.ForeignKey(
+        'offer.Range',
+        blank=True,
+        null=True,
+        on_delete=models.CASCADE,
+        verbose_name=_("Exclude range(default is no limit)"),
+        related_name='bonusExcludeRange'
+    )
+    
     
 class ECPayTrade(models.Model):
     merchantId = models.CharField(max_length=255)
