@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11786 2019-12-03 13:14:41Z Lavender $
+# $Id: views.py 11794 2019-12-11 16:31:08Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-12-03 22:14:41 +0900 (週二, 03 十二月 2019) $
-# $Revision: 11786 $ 
+# $Date: 2019-12-12 01:31:08 +0900 (週四, 12 十二月 2019) $
+# $Revision: 11794 $ 
 
 import json
 import logging
@@ -276,9 +276,13 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
             config = BonusSettings.objects.get(id=1)
             
             # receive
-            consumption = (
-                int(total.excl_tax) - config.consumption - 
-                int(shipping_charge.excl_tax))
+            if shipping_charge:
+                consumption = (
+                    int(total.excl_tax) - config.consumption - 
+                    int(shipping_charge.excl_tax))
+            else:
+                consumption = (
+                    int(total.excl_tax) - config.consumption)
             
             receive = 0
             if consumption >= 0:
@@ -561,8 +565,31 @@ def useBonus(request):
         return redirect("basket:summary")
     if not config.limit == -1 and quantity > config.limit:
         messages.error(
-            request, _("Use bonus over the upper limit %s.") % config.limit)
+            request, _("Use bonus over the upper limit %d.") % config.limit)
         return redirect("basket:summary")
+    
+    # include exclude 
+    totalCanUseBonus = 0
+    for line in request.basket.all_lines():
+        product = line.product
+        
+        if config.includeRange:
+            if not config.includeRange.contains_product(product):
+                messages.info(
+                    request, _("%s can't use bonus.") % product)
+                continue
+        if config.excludeRange:
+            if config.excludeRange.contains_product(product):
+                messages.info(
+                    request, _("%s can't use bonus.") % product)
+                continue
+                    
+        totalCanUseBonus += int(line.line_price_excl_tax)
+    
+    if quantity > totalCanUseBonus:
+        messages.info(
+            request, _("Only use %d bonus.") % totalCanUseBonus)
+        quantity = totalCanUseBonus
         
     value = quantity * config.discount
     
@@ -627,6 +654,195 @@ def useBonus(request):
     request.basket.vouchers.add(voucher)
         
     return redirect("basket:summary")
+    
+def updateBonus(request, *args, **kwargs):
+    pk = int(kwargs['pk'])
+    adjust = int(request.POST.get('adjust', 0))
+    user = get_user_model().objects.get(id=pk)
+    b, created = Bonus.objects.get_or_create(user=user)
+    
+    # update
+    b.quantity += adjust
+    b.save()
+    
+    # record
+    record = BonusRecord.objects.create(
+        user=user,
+        order=None,
+        adjust=adjust,
+    )
+    
+    messages.info(
+        request, _("Update success"))
+    
+    return redirect(reverse("dashboard:user-detail", kwargs={'pk': pk,}))
+
+    
+
+from django_tables2 import Column
+_UserTable = get_class('dashboard.users.tables', 'UserTable')
+
+class UserTable(_UserTable):
+    bonus = Column(accessor='bonus', verbose_name=_('Bonus'))
+    
+    class Meta(_UserTable.Meta):
+        sequence = ('check', 'email', 'name', 'active', 'staff',
+                    'date_registered', 'num_orders', 'bonus', 'actions',)
+    
+from oscar.apps.dashboard.users import \
+        views as dashboardUsersViews
+        
+dashboardUsersViews.IndexView.table_class = UserTable
+
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3289#ticket   
+@csrf_exempt
+def sendConfirmCode(request):
+
+    if request.POST:
+        email = request.POST.get('email', None)
+        timeStamp = request.POST.get('timeStamp', None)
+
+        if not email or not timeStamp:
+            raise PermissionDenied()
+
+        m = hashlib.md5()
+        m.update(email.encode())
+        m.update(timeStamp.encode())
+        code = m.hexdigest()[5:10]
+        
+        site = get_current_site(request)
+        
+        ctx = {
+            'code': code,
+            'site': site,
+        }
+        
+        t = get_template('shop/customer/emails/ConfirmCodeSubject.txt')
+        subject = t.render(ctx)
+        t = get_template('shop/customer/emails/ConfirmCodeBody.txt')
+        body = t.render(ctx)
+        
+        send_mail(
+            subject,
+            body,
+            settings.DEFAULT_FROM_EMAIL,
+            [request.POST['email']],
+            fail_silently=False,
+        )
+
+        s = _("We have send a confirmation code to %(email)s") % {
+                'email': email,}
+        return HttpResponse(json.dumps(s), content_type="application/json")
+        
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3290#ticket
+from oscar.apps.dashboard.orders import views as dashboardOrderViews
+from Iuno.shop.forms import OrderNoteForm
+
+OrderNote = get_model('order', 'OrderNote')
+
+def get_order_note_form(self):
+    kwargs = {
+        'order': self.object,
+        'user': self.request.user,
+        'data': None
+    }
+    if self.request.method == 'POST':
+        kwargs['data'] = self.request.POST
+    noteId = self.kwargs.get('note_id', None)
+    if noteId:
+        note = get_object_or_404(OrderNote, order=self.object, id=noteId)
+        if note.is_editable():
+            kwargs['instance'] = note
+    return OrderNoteForm(**kwargs)
+    
+dashboardOrderViews.OrderDetailView.get_order_note_form = get_order_note_form
+
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3284#ticket
+try:
+    import xapian
+
+    from oscar.apps.search import facets
+    from oscar.apps.search import forms as searchForms
+
+    def munge_query_facet(self, key, facet, clean_data):
+        clean_data[key] = {
+            'name': facet['name'],
+            'results': []}
+        # Loop over the queries in OSCAR_SEARCH_FACETS rather than the returned
+        # facet information from the search backend.
+        for field_value, query in facet['queries']:
+            field_name = facet['field']
+            is_faceted_already = field_name in self.selected_facets
+
+            match = '%s_exact:%s' % (field_name, query)
+            if match not in self.facet_counts['queries'][field_name]:
+                # This query was not returned
+                datum = {
+                    'name': field_value,
+                    'count': 0,
+                    'show_count': True,
+                    'disabled': True,
+                }
+            else:
+                count = self.facet_counts['queries'][field_name][match]
+                datum = {
+                    'name': field_value,
+                    'count': count,
+                    'show_count': not is_faceted_already,
+                    'disabled': count == 0 and not is_faceted_already,
+                    'selected': False,
+                }
+                if query in self.selected_facets.get("%s_exact" % field_name, []):
+                    # Selected
+                    datum['selected'] = True
+                    datum['show_count'] = True
+                    url = self.base_url.remove_query_param(
+                        'selected_facets', match)
+                    datum['deselect_url'] = self.strip_pagination(url)
+                else:
+                    url = self.base_url.append_query_param(
+                        'selected_facets', match)
+                    datum['select_url'] = self.strip_pagination(url)
+            clean_data[key]['results'].append(datum)
+           
+    def xapianSearch(self):
+        # We replace the 'search' method from FacetedSearchForm, so that we can
+        # handle range queries
+        # Note, we call super on a parent class as the default faceted view
+        # escapes everything (which doesn't work for price range queries)
+        sqs = super(searchForms.FacetedSearchForm, self).search()
+
+        # We need to process each facet to ensure that the field name and the
+        # value are quoted correctly and separately:
+        for field, values in self.selected_multi_facets.items():
+            if not values:
+                continue
+            if field in searchForms.VALID_FACET_QUERIES:
+                # Query facet - don't wrap value in speech marks and don't
+                # clean value. Query values should have been validated by this
+                # point and so we don't need to escape them.
+                q = ["%s:%s" % (field, v) for v in values]
+                sqs = sqs.narrow(" ".join(q))
+            else:
+                # Field facet - clean and quote the values
+                clean_values = [
+                    '"%s"' % sqs.query.clean(val) for val in values]
+                sqs = sqs.narrow('%s:(%s)' % (
+                    field, " OR ".join(clean_values)))
+
+        if self.is_valid() and 'sort_by' in self.cleaned_data:
+            sort_field = self.SORT_BY_MAP.get(
+                self.cleaned_data['sort_by'], None)
+            if sort_field:
+                sqs = sqs.order_by(sort_field)
+
+        return sqs
+            
+    facets.FacetMunger.munge_query_facet = munge_query_facet
+    searchForms.SearchForm.search = xapianSearch
+except Exception as e:
+    # no use xapian
+    pass
 
 # ------------------------------------------------------------------------------
 # /cathaybk/preview/
